Module path_picker

Module path_picker 

Shared filesystem path browser for TUI (directory or file pick).

Structs

PathPicker

Enums

PathPickerEvent
Result of handling a key press.
PathPickerFocus
PathPickerMode
Whether the user must pick a directory or a regular file.

Functions

resolve_browse_directory
Resolve a directory to list for the given user input.