Download state and management.
DownloadJob holds per-download progress/status.
DownloadManager owns the shared job list and spawns background tasks.
Structs
- Download
Job - A single background download job (for one ROM).
- Download
Manager - Owns the shared download list and spawns background download tasks.
Enums
- Download
Status - High-level status of a single download.
Functions
- download_
directory - Directory for ROM zip downloads (
ROMM_DOWNLOAD_DIRor./downloads). - unique_
zip_ path - Pick
stem.zip, thenstem__2.zip,stem__3.zip, … until the path does not exist.