Shared filesystem path browser for TUI (directory or file pick).
Structs
Enums
- Path
Picker Event - Result of handling a key press.
- Path
Picker Focus - Path
Picker Mode - Whether the user must pick a directory or a regular file.
Functions
- resolve_
browse_ directory - Resolve a directory to list for the given user input.