ResultScreen

Struct ResultScreen 

pub struct ResultScreen {
    pub raw: Value,
    pub highlighted_lines: Vec<Line<'static>>,
    pub scroll: usize,
    pub scrollbar_state: ScrollbarState,
    pub view_mode: ResultViewMode,
    pub table_selected: usize,
    pub table_row_count: usize,
    pub message: Option<String>,
}

Fields

raw: Valuehighlighted_lines: Vec<Line<'static>>scroll: usizescrollbar_state: ScrollbarStateview_mode: ResultViewModetable_selected: usizetable_row_count: usizemessage: Option<String>

Implementations

Source

impl ResultScreen

pub fn new( result: Value, endpoint_method: Option<&str>, endpoint_path: Option<&str>, ) -> Self

Create a result screen. If endpoint_method is “GET” and endpoint_path is “/api/roms” and the response has list items, table view is used as default.

pub fn collect_image_urls(value: &Value) -> Vec<String>

pub fn get_selected_item_value(&self) -> Option<Value>

Returns the selected row value when in table view (for opening detail screen).

pub fn scroll_down(&mut self, amount: usize)

pub fn scroll_up(&mut self, amount: usize)

pub fn table_next(&mut self)

pub fn table_previous(&mut self)

pub fn table_page_up(&mut self)

pub fn table_page_down(&mut self)

pub fn switch_view_mode(&mut self)

pub fn clear_message(&mut self)

pub fn render(&self, f: &mut Frame<'_>, area: Rect)